debug_fatal_with_metric

Macro debug_fatal_with_metric 

macro_rules! debug_fatal_with_metric {
    ($record:expr, $msg:literal $(, $arg:expr)*) => { ... };
}
Like debug_fatal!, but records the violation on a metric of the caller’s choosing instead of system_invariant_violations: $record is invoked with &mysten_metrics::Metrics when metrics are initialized. Use this when a violation has its own counter, and its own alert.